package v1
import "k8s.io/client-go/listers/autoscaling/v1"
Index ¶
- type HorizontalPodAutoscalerLister
- type HorizontalPodAutoscalerListerExpansion
- type HorizontalPodAutoscalerNamespaceLister
- type HorizontalPodAutoscalerNamespaceListerExpansion
Types ¶
type HorizontalPodAutoscalerLister ¶
type HorizontalPodAutoscalerLister interface {
// List lists all HorizontalPodAutoscalers in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.HorizontalPodAutoscaler, err error)
// HorizontalPodAutoscalers returns an object that can list and get HorizontalPodAutoscalers.
HorizontalPodAutoscalers(namespace string) HorizontalPodAutoscalerNamespaceLister
HorizontalPodAutoscalerListerExpansion
}
HorizontalPodAutoscalerLister helps list HorizontalPodAutoscalers. All objects returned here must be treated as read-only.
func NewHorizontalPodAutoscalerLister ¶
func NewHorizontalPodAutoscalerLister(indexer cache.Indexer) HorizontalPodAutoscalerLister
NewHorizontalPodAutoscalerLister returns a new HorizontalPodAutoscalerLister.
type HorizontalPodAutoscalerListerExpansion ¶
type HorizontalPodAutoscalerListerExpansion interface{}
HorizontalPodAutoscalerListerExpansion allows custom methods to be added to HorizontalPodAutoscalerLister.
type HorizontalPodAutoscalerNamespaceLister ¶
type HorizontalPodAutoscalerNamespaceLister interface {
// List lists all HorizontalPodAutoscalers in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.HorizontalPodAutoscaler, err error)
// Get retrieves the HorizontalPodAutoscaler from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1.HorizontalPodAutoscaler, error)
HorizontalPodAutoscalerNamespaceListerExpansion
}
HorizontalPodAutoscalerNamespaceLister helps list and get HorizontalPodAutoscalers. All objects returned here must be treated as read-only.
type HorizontalPodAutoscalerNamespaceListerExpansion ¶
type HorizontalPodAutoscalerNamespaceListerExpansion interface{}
HorizontalPodAutoscalerNamespaceListerExpansion allows custom methods to be added to HorizontalPodAutoscalerNamespaceLister.
Source Files ¶
expansion_generated.go horizontalpodautoscaler.go
- Version
- v0.31.13
- Published
- Sep 10, 2025
- Platform
- linux/amd64
- Imports
- 4 packages
- Last checked
- 24 minutes ago –
Tools for package owners.