package v1
import "k8s.io/client-go/listers/batch/v1"
Index ¶
Types ¶
type JobLister ¶
type JobLister interface {
// List lists all Jobs in the indexer.
List(selector labels.Selector) (ret []*v1.Job, err error)
// Jobs returns an object that can list and get Jobs.
Jobs(namespace string) JobNamespaceLister
JobListerExpansion
}
JobLister helps list Jobs.
func NewJobLister ¶
NewJobLister returns a new JobLister.
type JobListerExpansion ¶
type JobListerExpansion interface {
// GetPodJobs returns a list of Jobs that potentially
// match a Pod. Only the one specified in the Pod's ControllerRef
// will actually manage it.
// Returns an error only if no matching Jobs are found.
GetPodJobs(pod *v1.Pod) (jobs []batch.Job, err error)
}
JobListerExpansion allows custom methods to be added to JobLister.
type JobNamespaceLister ¶
type JobNamespaceLister interface {
// List lists all Jobs in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1.Job, err error)
// Get retrieves the Job from the indexer for a given namespace and name.
Get(name string) (*v1.Job, error)
JobNamespaceListerExpansion
}
JobNamespaceLister helps list and get Jobs.
type JobNamespaceListerExpansion ¶
type JobNamespaceListerExpansion interface{}
JobNamespaceListerExpansion allows custom methods to be added to JobNamespaceLister.
Source Files ¶
expansion_generated.go job.go job_expansion.go
- Version
- v8.0.0+incompatible
- Published
- Jun 28, 2018
- Platform
- linux/amd64
- Imports
- 7 packages
- Last checked
- 15 seconds ago –
Tools for package owners.