package v1
import "k8s.io/client-go/listers/flowcontrol/v1"
Index ¶
- type FlowSchemaLister
- type FlowSchemaListerExpansion
- type PriorityLevelConfigurationLister
- type PriorityLevelConfigurationListerExpansion
Types ¶
type FlowSchemaLister ¶
type FlowSchemaLister interface {
// List lists all FlowSchemas in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*flowcontrolv1.FlowSchema, err error)
// Get retrieves the FlowSchema from the index for a given name.
// Objects returned here must be treated as read-only.
Get(name string) (*flowcontrolv1.FlowSchema, error)
FlowSchemaListerExpansion
}
FlowSchemaLister helps list FlowSchemas. All objects returned here must be treated as read-only.
func NewFlowSchemaLister ¶
func NewFlowSchemaLister(indexer cache.Indexer) FlowSchemaLister
NewFlowSchemaLister returns a new FlowSchemaLister.
type FlowSchemaListerExpansion ¶
type FlowSchemaListerExpansion interface{}
FlowSchemaListerExpansion allows custom methods to be added to FlowSchemaLister.
type PriorityLevelConfigurationLister ¶
type PriorityLevelConfigurationLister interface {
// List lists all PriorityLevelConfigurations in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*flowcontrolv1.PriorityLevelConfiguration, err error)
// Get retrieves the PriorityLevelConfiguration from the index for a given name.
// Objects returned here must be treated as read-only.
Get(name string) (*flowcontrolv1.PriorityLevelConfiguration, error)
PriorityLevelConfigurationListerExpansion
}
PriorityLevelConfigurationLister helps list PriorityLevelConfigurations. All objects returned here must be treated as read-only.
func NewPriorityLevelConfigurationLister ¶
func NewPriorityLevelConfigurationLister(indexer cache.Indexer) PriorityLevelConfigurationLister
NewPriorityLevelConfigurationLister returns a new PriorityLevelConfigurationLister.
type PriorityLevelConfigurationListerExpansion ¶
type PriorityLevelConfigurationListerExpansion interface{}
PriorityLevelConfigurationListerExpansion allows custom methods to be added to PriorityLevelConfigurationLister.
Source Files ¶
expansion_generated.go flowschema.go prioritylevelconfiguration.go
- Version
- v0.34.5
- Published
- Feb 27, 2026
- Platform
- linux/amd64
- Imports
- 4 packages
- Last checked
- 1 hour ago –
Tools for package owners.