package v1beta1
import "k8s.io/client-go/listers/node/v1beta1"
Index ¶
Types ¶
type RuntimeClassLister ¶
type RuntimeClassLister interface {
// List lists all RuntimeClasses in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*nodev1beta1.RuntimeClass, err error)
// Get retrieves the RuntimeClass from the index for a given name.
// Objects returned here must be treated as read-only.
Get(name string) (*nodev1beta1.RuntimeClass, error)
RuntimeClassListerExpansion
}
RuntimeClassLister helps list RuntimeClasses. All objects returned here must be treated as read-only.
func NewRuntimeClassLister ¶
func NewRuntimeClassLister(indexer cache.Indexer) RuntimeClassLister
NewRuntimeClassLister returns a new RuntimeClassLister.
type RuntimeClassListerExpansion ¶
type RuntimeClassListerExpansion interface{}
RuntimeClassListerExpansion allows custom methods to be added to RuntimeClassLister.
Source Files ¶
expansion_generated.go runtimeclass.go
- Version
- v0.33.6
- Published
- Nov 12, 2025
- Platform
- linux/amd64
- Imports
- 4 packages
- Last checked
- 1 hour ago –
Tools for package owners.