client-gok8s.io/client-go/listers/resource/v1alpha3 Index | Files

package v1alpha3

import "k8s.io/client-go/listers/resource/v1alpha3"

Index

Types

type DeviceTaintRuleLister

type DeviceTaintRuleLister interface {
	// List lists all DeviceTaintRules in the indexer.
	// Objects returned here must be treated as read-only.
	List(selector labels.Selector) (ret []*resourcev1alpha3.DeviceTaintRule, err error)
	// Get retrieves the DeviceTaintRule from the index for a given name.
	// Objects returned here must be treated as read-only.
	Get(name string) (*resourcev1alpha3.DeviceTaintRule, error)
	DeviceTaintRuleListerExpansion
}

DeviceTaintRuleLister helps list DeviceTaintRules. All objects returned here must be treated as read-only.

func NewDeviceTaintRuleLister

func NewDeviceTaintRuleLister(indexer cache.Indexer) DeviceTaintRuleLister

NewDeviceTaintRuleLister returns a new DeviceTaintRuleLister.

type DeviceTaintRuleListerExpansion

type DeviceTaintRuleListerExpansion interface{}

DeviceTaintRuleListerExpansion allows custom methods to be added to DeviceTaintRuleLister.

type ResourcePoolStatusRequestLister

type ResourcePoolStatusRequestLister interface {
	// List lists all ResourcePoolStatusRequests in the indexer.
	// Objects returned here must be treated as read-only.
	List(selector labels.Selector) (ret []*resourcev1alpha3.ResourcePoolStatusRequest, err error)
	// Get retrieves the ResourcePoolStatusRequest from the index for a given name.
	// Objects returned here must be treated as read-only.
	Get(name string) (*resourcev1alpha3.ResourcePoolStatusRequest, error)
	ResourcePoolStatusRequestListerExpansion
}

ResourcePoolStatusRequestLister helps list ResourcePoolStatusRequests. All objects returned here must be treated as read-only.

func NewResourcePoolStatusRequestLister

func NewResourcePoolStatusRequestLister(indexer cache.Indexer) ResourcePoolStatusRequestLister

NewResourcePoolStatusRequestLister returns a new ResourcePoolStatusRequestLister.

type ResourcePoolStatusRequestListerExpansion

type ResourcePoolStatusRequestListerExpansion interface{}

ResourcePoolStatusRequestListerExpansion allows custom methods to be added to ResourcePoolStatusRequestLister.

Source Files

devicetaintrule.go expansion_generated.go resourcepoolstatusrequest.go

Version
v0.36.0 (latest)
Published
Apr 22, 2026
Platform
linux/amd64
Imports
4 packages
Last checked
1 second ago

Tools for package owners.