client-gok8s.io/client-go/listers/scheduling/v1alpha1 Index | Files

package v1alpha1

import "k8s.io/client-go/listers/scheduling/v1alpha1"

Index

Types

type PriorityClassLister

type PriorityClassLister interface {
	// List lists all PriorityClasses in the indexer.
	// Objects returned here must be treated as read-only.
	List(selector labels.Selector) (ret []*schedulingv1alpha1.PriorityClass, err error)
	// Get retrieves the PriorityClass from the index for a given name.
	// Objects returned here must be treated as read-only.
	Get(name string) (*schedulingv1alpha1.PriorityClass, error)
	PriorityClassListerExpansion
}

PriorityClassLister helps list PriorityClasses. All objects returned here must be treated as read-only.

func NewPriorityClassLister

func NewPriorityClassLister(indexer cache.Indexer) PriorityClassLister

NewPriorityClassLister returns a new PriorityClassLister.

type PriorityClassListerExpansion

type PriorityClassListerExpansion interface{}

PriorityClassListerExpansion allows custom methods to be added to PriorityClassLister.

type WorkloadLister

type WorkloadLister interface {
	// List lists all Workloads in the indexer.
	// Objects returned here must be treated as read-only.
	List(selector labels.Selector) (ret []*schedulingv1alpha1.Workload, err error)
	// Workloads returns an object that can list and get Workloads.
	Workloads(namespace string) WorkloadNamespaceLister
	WorkloadListerExpansion
}

WorkloadLister helps list Workloads. All objects returned here must be treated as read-only.

func NewWorkloadLister

func NewWorkloadLister(indexer cache.Indexer) WorkloadLister

NewWorkloadLister returns a new WorkloadLister.

type WorkloadListerExpansion

type WorkloadListerExpansion interface{}

WorkloadListerExpansion allows custom methods to be added to WorkloadLister.

type WorkloadNamespaceLister

type WorkloadNamespaceLister interface {
	// List lists all Workloads in the indexer for a given namespace.
	// Objects returned here must be treated as read-only.
	List(selector labels.Selector) (ret []*schedulingv1alpha1.Workload, err error)
	// Get retrieves the Workload from the indexer for a given namespace and name.
	// Objects returned here must be treated as read-only.
	Get(name string) (*schedulingv1alpha1.Workload, error)
	WorkloadNamespaceListerExpansion
}

WorkloadNamespaceLister helps list and get Workloads. All objects returned here must be treated as read-only.

type WorkloadNamespaceListerExpansion

type WorkloadNamespaceListerExpansion interface{}

WorkloadNamespaceListerExpansion allows custom methods to be added to WorkloadNamespaceLister.

Source Files

expansion_generated.go priorityclass.go workload.go

Version
v0.35.4
Published
Apr 15, 2026
Platform
linux/amd64
Imports
4 packages
Last checked
1 hour ago

Tools for package owners.