client-gok8s.io/client-go/listers/scheduling/v1alpha2 Index | Files

package v1alpha2

import "k8s.io/client-go/listers/scheduling/v1alpha2"

Index

Types

type PodGroupLister

type PodGroupLister interface {
	// List lists all PodGroups in the indexer.
	// Objects returned here must be treated as read-only.
	List(selector labels.Selector) (ret []*schedulingv1alpha2.PodGroup, err error)
	// PodGroups returns an object that can list and get PodGroups.
	PodGroups(namespace string) PodGroupNamespaceLister
	PodGroupListerExpansion
}

PodGroupLister helps list PodGroups. All objects returned here must be treated as read-only.

func NewPodGroupLister

func NewPodGroupLister(indexer cache.Indexer) PodGroupLister

NewPodGroupLister returns a new PodGroupLister.

type PodGroupListerExpansion

type PodGroupListerExpansion interface{}

PodGroupListerExpansion allows custom methods to be added to PodGroupLister.

type PodGroupNamespaceLister

type PodGroupNamespaceLister interface {
	// List lists all PodGroups in the indexer for a given namespace.
	// Objects returned here must be treated as read-only.
	List(selector labels.Selector) (ret []*schedulingv1alpha2.PodGroup, err error)
	// Get retrieves the PodGroup from the indexer for a given namespace and name.
	// Objects returned here must be treated as read-only.
	Get(name string) (*schedulingv1alpha2.PodGroup, error)
	PodGroupNamespaceListerExpansion
}

PodGroupNamespaceLister helps list and get PodGroups. All objects returned here must be treated as read-only.

type PodGroupNamespaceListerExpansion

type PodGroupNamespaceListerExpansion interface{}

PodGroupNamespaceListerExpansion allows custom methods to be added to PodGroupNamespaceLister.

type WorkloadLister

type WorkloadLister interface {
	// List lists all Workloads in the indexer.
	// Objects returned here must be treated as read-only.
	List(selector labels.Selector) (ret []*schedulingv1alpha2.Workload, err error)
	// Workloads returns an object that can list and get Workloads.
	Workloads(namespace string) WorkloadNamespaceLister
	WorkloadListerExpansion
}

WorkloadLister helps list Workloads. All objects returned here must be treated as read-only.

func NewWorkloadLister

func NewWorkloadLister(indexer cache.Indexer) WorkloadLister

NewWorkloadLister returns a new WorkloadLister.

type WorkloadListerExpansion

type WorkloadListerExpansion interface{}

WorkloadListerExpansion allows custom methods to be added to WorkloadLister.

type WorkloadNamespaceLister

type WorkloadNamespaceLister interface {
	// List lists all Workloads in the indexer for a given namespace.
	// Objects returned here must be treated as read-only.
	List(selector labels.Selector) (ret []*schedulingv1alpha2.Workload, err error)
	// Get retrieves the Workload from the indexer for a given namespace and name.
	// Objects returned here must be treated as read-only.
	Get(name string) (*schedulingv1alpha2.Workload, error)
	WorkloadNamespaceListerExpansion
}

WorkloadNamespaceLister helps list and get Workloads. All objects returned here must be treated as read-only.

type WorkloadNamespaceListerExpansion

type WorkloadNamespaceListerExpansion interface{}

WorkloadNamespaceListerExpansion allows custom methods to be added to WorkloadNamespaceLister.

Source Files

expansion_generated.go podgroup.go workload.go

Version
v0.36.0 (latest)
Published
Apr 22, 2026
Platform
linux/amd64
Imports
4 packages
Last checked
6 days ago

Tools for package owners.