package v1alpha1
import "k8s.io/client-go/listers/storage/v1alpha1"
Index ¶
- type CSIStorageCapacityLister
- type CSIStorageCapacityListerExpansion
- type CSIStorageCapacityNamespaceLister
- type CSIStorageCapacityNamespaceListerExpansion
- type VolumeAttachmentLister
- type VolumeAttachmentListerExpansion
- type VolumeAttributesClassLister
- type VolumeAttributesClassListerExpansion
Types ¶
type CSIStorageCapacityLister ¶
type CSIStorageCapacityLister interface {
// List lists all CSIStorageCapacities in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.CSIStorageCapacity, err error)
// CSIStorageCapacities returns an object that can list and get CSIStorageCapacities.
CSIStorageCapacities(namespace string) CSIStorageCapacityNamespaceLister
CSIStorageCapacityListerExpansion
}
CSIStorageCapacityLister helps list CSIStorageCapacities. All objects returned here must be treated as read-only.
func NewCSIStorageCapacityLister ¶
func NewCSIStorageCapacityLister(indexer cache.Indexer) CSIStorageCapacityLister
NewCSIStorageCapacityLister returns a new CSIStorageCapacityLister.
type CSIStorageCapacityListerExpansion ¶
type CSIStorageCapacityListerExpansion interface{}
CSIStorageCapacityListerExpansion allows custom methods to be added to CSIStorageCapacityLister.
type CSIStorageCapacityNamespaceLister ¶
type CSIStorageCapacityNamespaceLister interface {
// List lists all CSIStorageCapacities in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.CSIStorageCapacity, err error)
// Get retrieves the CSIStorageCapacity from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.CSIStorageCapacity, error)
CSIStorageCapacityNamespaceListerExpansion
}
CSIStorageCapacityNamespaceLister helps list and get CSIStorageCapacities. All objects returned here must be treated as read-only.
type CSIStorageCapacityNamespaceListerExpansion ¶
type CSIStorageCapacityNamespaceListerExpansion interface{}
CSIStorageCapacityNamespaceListerExpansion allows custom methods to be added to CSIStorageCapacityNamespaceLister.
type VolumeAttachmentLister ¶
type VolumeAttachmentLister interface {
// List lists all VolumeAttachments in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.VolumeAttachment, err error)
// Get retrieves the VolumeAttachment from the index for a given name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.VolumeAttachment, error)
VolumeAttachmentListerExpansion
}
VolumeAttachmentLister helps list VolumeAttachments. All objects returned here must be treated as read-only.
func NewVolumeAttachmentLister ¶
func NewVolumeAttachmentLister(indexer cache.Indexer) VolumeAttachmentLister
NewVolumeAttachmentLister returns a new VolumeAttachmentLister.
type VolumeAttachmentListerExpansion ¶
type VolumeAttachmentListerExpansion interface{}
VolumeAttachmentListerExpansion allows custom methods to be added to VolumeAttachmentLister.
type VolumeAttributesClassLister ¶
type VolumeAttributesClassLister interface {
// List lists all VolumeAttributesClasses in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.VolumeAttributesClass, err error)
// Get retrieves the VolumeAttributesClass from the index for a given name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.VolumeAttributesClass, error)
VolumeAttributesClassListerExpansion
}
VolumeAttributesClassLister helps list VolumeAttributesClasses. All objects returned here must be treated as read-only.
func NewVolumeAttributesClassLister ¶
func NewVolumeAttributesClassLister(indexer cache.Indexer) VolumeAttributesClassLister
NewVolumeAttributesClassLister returns a new VolumeAttributesClassLister.
type VolumeAttributesClassListerExpansion ¶
type VolumeAttributesClassListerExpansion interface{}
VolumeAttributesClassListerExpansion allows custom methods to be added to VolumeAttributesClassLister.
Source Files ¶
csistoragecapacity.go expansion_generated.go volumeattachment.go volumeattributesclass.go
- Version
- v0.31.11
- Published
- Jul 16, 2025
- Platform
- linux/amd64
- Imports
- 4 packages
- Last checked
- 13 minutes ago –
Tools for package owners.