package v1alpha1
import "k8s.io/client-go/listers/storagemigration/v1alpha1"
Index ¶
Types ¶
type StorageVersionMigrationLister ¶
type StorageVersionMigrationLister interface {
// List lists all StorageVersionMigrations in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.StorageVersionMigration, err error)
// Get retrieves the StorageVersionMigration from the index for a given name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.StorageVersionMigration, error)
StorageVersionMigrationListerExpansion
}
StorageVersionMigrationLister helps list StorageVersionMigrations. All objects returned here must be treated as read-only.
func NewStorageVersionMigrationLister ¶
func NewStorageVersionMigrationLister(indexer cache.Indexer) StorageVersionMigrationLister
NewStorageVersionMigrationLister returns a new StorageVersionMigrationLister.
type StorageVersionMigrationListerExpansion ¶
type StorageVersionMigrationListerExpansion interface{}
StorageVersionMigrationListerExpansion allows custom methods to be added to StorageVersionMigrationLister.
Source Files ¶
expansion_generated.go storageversionmigration.go
- Version
- v0.31.13
- Published
- Sep 10, 2025
- Platform
- linux/amd64
- Imports
- 4 packages
- Last checked
- 5 minutes ago –
Tools for package owners.