package v1alpha3
import "k8s.io/client-go/listers/resource/v1alpha3"
Index ¶
Types ¶
type DeviceTaintRuleLister ¶
type DeviceTaintRuleLister interface {
// List lists all DeviceTaintRules in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*resourcev1alpha3.DeviceTaintRule, err error)
// Get retrieves the DeviceTaintRule from the index for a given name.
// Objects returned here must be treated as read-only.
Get(name string) (*resourcev1alpha3.DeviceTaintRule, error)
DeviceTaintRuleListerExpansion
}
DeviceTaintRuleLister helps list DeviceTaintRules. All objects returned here must be treated as read-only.
func NewDeviceTaintRuleLister ¶
func NewDeviceTaintRuleLister(indexer cache.Indexer) DeviceTaintRuleLister
NewDeviceTaintRuleLister returns a new DeviceTaintRuleLister.
type DeviceTaintRuleListerExpansion ¶
type DeviceTaintRuleListerExpansion interface{}
DeviceTaintRuleListerExpansion allows custom methods to be added to DeviceTaintRuleLister.
Source Files ¶
devicetaintrule.go expansion_generated.go
- Version
- v0.35.2
- Published
- Feb 27, 2026
- Platform
- linux/amd64
- Imports
- 4 packages
- Last checked
- 22 minutes ago –
Tools for package owners.